import os
import requests

def lambda_handler(event, context):

    # Get environment variables
    url = os.environ['NGFW_ENDPOINT']

    # Get values from event
    detail = event.get('detail', None)
    if not detail:
        print('No details were associated with this event.')
        return

    event_type = detail.get('type', None)
    if not event_type:
        print('No event type was associated with this event.')
        return

    service = detail.get('service', None)
    if not service:
        print('No service was associated with this event.')
        return

    action = service.get('action', None)
    if not action:
        print('No action was associated with this event.')
        return

    call_action = action.get('awsApiCallAction', None)
    if not call_action:
        print('No AWS api call action was associated with this event.')
        return

    remote_details = call_action.get('remoteIpDetails', None)
    if not remote_details:
        print('No remote details were associated with this event.')
        return
    
    ip_address = remote_details.get('ipAddressV4', None)
    if not ip_address:
        print('No IP Address was associated with this event.')
        return

    # Build data to be sent
    data = {
        'event_type': event_type,
        'remote_ip': ip_address
    }
    
    # Send request
    try:
        requests.post(url, json=data)
    except requests.Timeout:
        print('There was a timeout error when attempting to send the event to the endpoint %s.', url)
        return
    
    # Return
    print('Event successfully sent to NGFW endpoint.')
    return
